/**
 * @module botbuilder
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import type { ChannelServiceHandlerBase } from './channelServiceHandlerBase';
import { WebRequest, WebResponse } from './interfaces';
export type RouteHandler = (request: WebRequest, response: WebResponse) => void;
/**
 * Interface representing an Express Application or a Restify Server.
 */
export interface WebServer {
    get: (path: string, handler: RouteHandler) => void;
    post: (path: string, handler: RouteHandler) => void;
    put: (path: string, handler: RouteHandler) => void;
    del?: (path: string, handler: RouteHandler) => void;
    delete?: (path: string, handler: RouteHandler) => void;
}
/**
 * Routes the API calls with the ChannelServiceHandler methods.
 */
export declare class ChannelServiceRoutes {
    private readonly channelServiceHandler;
    /**
     * @param channelServiceHandler The channel service handler.
     */
    constructor(channelServiceHandler: ChannelServiceHandlerBase);
    /**
     * Registers all Channel Service paths on the provided WebServer.
     *
     * @param server WebServer
     * @param basePath Optional basePath which is appended before the service's REST API is configured on the WebServer.
     */
    register(server: WebServer, basePath?: string): void;
    /**
     * @private
     */
    private processSendToConversation;
    /**
     * @private
     */
    private processReplyToActivity;
    /**
     * @private
     */
    private processUpdateActivity;
    /**
     * @private
     */
    private processDeleteActivity;
    /**
     * @private
     */
    private processGetActivityMembers;
    /**
     * @private
     */
    private processCreateConversation;
    /**
     * @private
     */
    private processGetConversations;
    /**
     * @private
     */
    private processGetConversationMembers;
    /**
     * @private
     */
    private processGetConversationMember;
    /**
     * @private
     */
    private processGetConversationPagedMembers;
    /**
     * @private
     */
    private processDeleteConversationMember;
    /**
     * @private
     */
    private processSendConversationHistory;
    /**
     * @private
     */
    private processUploadAttachment;
    /**
     * @private
     */
    private static readActivity;
    /**
     * @private
     */
    private static readBody;
    /**
     * @private
     */
    private static handleError;
}
//# sourceMappingURL=channelServiceRoutes.d.ts.map